@@ -31,3 +31,7 @@ def str_to_datetime(date_string):
 
 def str_to_date(date_string):
     return str_to_datetime(date_string).date()
+
+def last_day_of_month(any_day):
+    next_month = any_day.replace(day=28) + timedelta(days=4)
+    return next_month - timedelta(days=next_month.day)
